HTTP Routing Table — IVRE documentation

# HTTP Routing Table

/(subdb:re:scans|view) | /config | /flows | /ipdata | /passivedns

| /(subdb:re:scans|view) |
| `GET /(subdb:re:scans|view)` |
| `GET /(subdb:re:scans|view)/(action:re:onlyips|ipsports|timeline|coordinates|countopenports|diffcats)` |
| `GET /(subdb:re:scans|view)/count` |
| `GET /(subdb:re:scans|view)/top/(field:path)` |
| `POST /(subdb:re:scans|view)` |
| /config |
| `GET /config` |
| /flows |
| `GET /flows` |
| /ipdata |
| `GET /ipdata/(addr)` |
| /passivedns |
| `GET /passivedns/(query:path)` |